#
# spec file for package python-rich-click
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-rich-click
Version:        1.7.1
Release:        1.1
Summary:        Format click help output nicely with rich
License:        MIT
URL:            https://github.com/ewels/rich-click
Source:         https://files.pythonhosted.org/packages/source/r/rich-click/rich-click-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-click >= 8
Requires:       python-rich >= 10.7.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module click >= 8}
BuildRequires:  %{python_module rich >= 10.7.0}
# /SECTION
%python_subpackages

%description
Format click help output nicely with rich.

%prep
%setup -q -n rich-click-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/rich-click
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative rich-click

%postun
%python_uninstall_alternative rich-click

#%%check
# No tests yet https://github.com/ewels/rich-click/issues/25

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/rich-click
%{python_sitelib}/*rich[_-]click*/

%changelog
* Wed Dec 13 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.2:
  * Add support for rich formatting in epilog text [#146]
  * Fix bug with `rich-click` CLI not working with Python 3.12.
    [#141]
  * Fix compatibility issue with `dbt-core` CLI. [#140]
  * Extends Click's `HelpFormatter` class
  * Creates a `HelpConfiguration` class that doubles the current
    module-level settings
  * Added a decorator that allows the `HelpConfiguration` to be
    passed into Click via the supported `context_settings`
    argument provided by the `Command` and `Group` classes.
  * The Rich Console object can also be configured per command
    and is distinct from the Console instance used internally by
    the formatter. The `RichHelpFormatter` creates a console
    based on the `RichHelpConfiguration` as the tight coupling
    between the Formatter and Click's internals make it difficult
    to allow the Console to be configured externally (i.e. one
    example is that Click expects help formatting to be
    buffered).
  * Created a `RichContext` class to allow creation of the custom
    formatter.
  * The Rich Command, Group, and Context now expose the `Console`
    and `RichHelpConfiguration` properties.
  * Added contributor VSCode settings
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 1.6.1:
  * Don't show metavars for feature switch options [#100]
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.6.0
  * warning Removed support for Typer warning
  * Please use the native Typer functionality instead.
  * Added self-updating automated readme screengrabs using rich-codex
  * Fix AssertionError when using click command call #94
* Thu Sep  1 2022 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.5.2
